@@ -1,2 +1,2 @@
 """Define package-level imports."""
-from .api import MindHomeAPI  # noqa
+from .api import get_api  # noqa
